@@ -117,7 +117,7 @@
 #'   area = "fr", 
 #'   cluster_name = "my_cluster",
 #'   prepro_data = data.frame(
-#'     v1 = rep(7, 365), # column name doesn't matter
+#'     v1 = rep(7, 365), # column name does not matter
 #'     v2 = rep(27, 365),
 #'     v3 = rep(0.05, 365),
 #'     v4 = rep(0.12, 365),
@@ -132,7 +132,7 @@
 #' createCluster(
 #'   area = "fr", 
 #'   cluster_name = "my_cluster",
-#'   prepro_modulation =  = matrix(
+#'   prepro_modulation = matrix(
 #'     data = c(rep(1, times = 365 * 24 * 3),
 #'              rep(0, times = 365 * 24 * 1)),
 #'     ncol = 4
@@ -144,7 +144,7 @@
 #'   area = "fr", 
 #'   cluster_name = "my_cluster",
 #'   prepro_modulation = data.frame(
-#'     var1 = rep(0, 8760), # column name doesn't matter
+#'     var1 = rep(0, 8760), # column name does not matter
 #'     var2 = rep(1, 8760),
 #'     var3 = rep(0, 8760),
 #'     var4 = rep(1, 8760)
@@ -290,7 +290,7 @@ createClusterRES <- function(area,
   if (!NROW(prepro_modulation) %in% c(0, 8736, 8760)) {
     stop("Number of rows for modulation data must be 0 or 8760")
   }
-  if (!NCOL(prepro_modulation) %in% c(1, 4)) {
+  if (!NCOL(prepro_modulation) %in% c(0, 1, 4)) { # issue 115 NCOL NULL return
     stop("Number of cols for modulation data must be 0 or 4")
   }
   
